Module compat

Module compat 

quant-codec-core trait implementations for fib-quant.

This module implements the VectorCodec, CodecProfile, and KvCacheCodec traits from quant-codec-core so that fib-quant can be used through the shared codec trait boundary by poly-kv, quant-governor, and scr-runtime-compression.

This is an additive compatibility layer behind the compat feature gate. It does not change any existing fib-quant APIs.

Structs

FibKvCodec
KV cache codec wrapping fib-quant’s KV compression.

Constants

FIB_QUANT_CODEC_ID
Codec ID string for fib-quant.

Functions

eval_compress
Run a compression eval using the quant-codec-core EvalReport type.