pub struct FibBenchmarkCorpus {
pub vectors: Vec<Vec<f32>>,
pub queries: Vec<Vec<f32>>,
pub ground_truth_topk: Vec<Vec<usize>>,
pub k: usize,
pub label: String,
}Expand description
A corpus of database vectors, queries, and ground-truth top-K labels.
The ground_truth_topk must have the same length as queries, and each
entry must contain the indices of the k most similar database vectors
(by exact cosine similarity) for the corresponding query.
Fields
vectors: Vec<Vec<f32>>Database vectors to be encoded.
queries: Vec<Vec<f32>>Query vectors.
ground_truth_topk: Vec<Vec<usize>>For each query, the indices of the true top-K most similar database vectors.
k: usizeK value for recall@K.
label: StringHuman-readable corpus identifier.
Implementations