KvTensorShapeV1

Struct KvTensorShapeV1 

pub struct KvTensorShapeV1 {
    pub schema_version: String,
    pub role: KvRole,
    pub attention_kind: KvAttentionKind,
    pub batch: u32,
    pub layers: u32,
    pub kv_heads: u32,
    pub query_heads: u32,
    pub tokens: u32,
    pub head_dim: u32,
    pub dtype: KvDType,
    pub rope_state: KvRopeState,
}
Logical KV tensor shape.

Fields

schema_version: String

Stable schema marker.

role: KvRole

Key or value role.

attention_kind: KvAttentionKind

Attention head sharing geometry.

batch: u32

Batch count.

layers: u32

Layer count.

kv_heads: u32

KV head count.

query_heads: u32

Query head count.

tokens: u32

Token count.

head_dim: u32

Per-head channel dimension.

dtype: KvDType

Source dtype.

rope_state: KvRopeState

Key RoPE state or not-applicable for values.

Implementations

Source

impl KvTensorShapeV1

pub fn new( role: KvRole, attention_kind: KvAttentionKind, batch: u32, layers: u32, kv_heads: u32, query_heads: u32, tokens: u32, head_dim: u32, dtype: KvDType, rope_state: KvRopeState, ) -> Self

Create a shape with the v1 schema marker.

pub fn validate(&self) -> Result<()>

Validate shape invariants that are independent of compression profile.

pub fn validate_block_dim(&self, block_dim: u32) -> Result<()>

Validate that the head dimension can be directly compressed by a FibQuant block.

pub fn vector_count(&self) -> Result<usize>

Number of [batch, layer, kv_head, token] vectors.

pub fn element_count(&self) -> Result<usize>

Number of f32 scalar values in canonical contiguous form.

pub fn digest(&self) -> Result<String>

Stable digest over the explicit shape.