pub struct MultiLevelResidualCodebookV1 {
pub levels: Vec<ResidualCodebookV1>,
pub total_bits: u32,
}Expand description
Multi-level residual codebook container.
Holds all residual codebooks for a multi-level additive quantizer. Each level’s codebook captures the residual left after encoding with all previous levels.
Fields
levels: Vec<ResidualCodebookV1>Each level’s residual codebook (levels[0] = first residual level, etc.).
total_bits: u32Sum of bits per index across all residual levels (main bits not included).
Implementations