pub struct KvTensorShapeV1 {
pub schema_version: String,
pub role: KvRole,
pub attention_kind: KvAttentionKind,
pub batch: u32,
pub layers: u32,
pub kv_heads: u32,
pub query_heads: u32,
pub tokens: u32,
pub head_dim: u32,
pub dtype: KvDType,
pub rope_state: KvRopeState,
}Expand description
Logical KV tensor shape.
Fields
schema_version: StringStable schema marker.
role: KvRoleKey or value role.
attention_kind: KvAttentionKindAttention head sharing geometry.
batch: u32Batch count.
layers: u32Layer count.
kv_heads: u32KV head count.
query_heads: u32Query head count.
tokens: u32Token count.
head_dim: u32Per-head channel dimension.
dtype: KvDTypeSource dtype.
rope_state: KvRopeStateKey RoPE state or not-applicable for values.
Implementations
Sourceimpl KvTensorShapeV1
impl KvTensorShapeV1
Sourcepub fn new(
role: KvRole,
attention_kind: KvAttentionKind,
batch: u32,
layers: u32,
kv_heads: u32,
query_heads: u32,
tokens: u32,
head_dim: u32,
dtype: KvDType,
rope_state: KvRopeState,
) -> Self
pub fn new( role: KvRole, attention_kind: KvAttentionKind, batch: u32, layers: u32, kv_heads: u32, query_heads: u32, tokens: u32, head_dim: u32, dtype: KvDType, rope_state: KvRopeState, ) -> Self
Create a shape with the v1 schema marker.
Sourcepub fn validate(&self) -> Result<()>
pub fn validate(&self) -> Result<()>
Validate shape invariants that are independent of compression profile.
Sourcepub fn validate_block_dim(&self, block_dim: u32) -> Result<()>
pub fn validate_block_dim(&self, block_dim: u32) -> Result<()>
Validate that the head dimension can be directly compressed by a FibQuant block.
Sourcepub fn vector_count(&self) -> Result<usize>
pub fn vector_count(&self) -> Result<usize>
Number of [batch, layer, kv_head, token] vectors.
Sourcepub fn element_count(&self) -> Result<usize>
pub fn element_count(&self) -> Result<usize>
Number of f32 scalar values in canonical contiguous form.