Structs
- FibQuant
Profile V1 - Stable profile for paper-faithful FibQuant codebooks and payloads.
Enums
- Direction
Method - Direction initialization method.
- Empty
Cell Policy - Empty-cell handling during Lloyd-Max refinement.
- Norm
Format - Norm payload representation.
- Radius
Method - Radius initialization method.
- Source
Mode - Source used for training samples.
Constants
- MAX_
AMBIENT_ DIM - Maximum ambient dimension accepted by the alpha profile validator.
- MAX_
BLOCK_ DIM - Maximum block dimension accepted by the alpha profile validator.
- MAX_
CODEBOOK_ SIZE - Maximum codebook size accepted by the alpha profile validator.
- MAX_
CODEBOOK_ VALUES - Maximum number of scalar values in an
N x kcodebook. - MAX_
PACKED_ INDEX_ BITS - Maximum bits in a packed fixed-rate payload.
- MAX_
ROTATION_ MATRIX_ VALUES - Maximum number of scalar values in a dense rotation matrix.
- MAX_
TRAINING_ SAMPLES - Maximum Lloyd training samples accepted by the alpha profile validator.
- PROFILE_
SCHEMA
Functions
- wire_
index_ bits - Return the fixed wire width for one index in
[0, N).